@@ -9,20 +9,20 @@
 #  ifndef LIBCPP_HOCON_EXPORT
 #    ifdef libcpp_hocon_EXPORTS
         /* We are building this library */
-#      define LIBCPP_HOCON_EXPORT 
+#      define LIBCPP_HOCON_EXPORT __attribute__((visibility("default")))
 #    else
         /* We are using this library */
-#      define LIBCPP_HOCON_EXPORT 
+#      define LIBCPP_HOCON_EXPORT __attribute__((visibility("default")))
 #    endif
 #  endif
 
 #  ifndef LIBCPP_HOCON_NO_EXPORT
-#    define LIBCPP_HOCON_NO_EXPORT 
+#    define LIBCPP_HOCON_NO_EXPORT __attribute__((visibility("hidden")))
 #  endif
 #endif
 
 #ifndef LIBCPP_HOCON_DEPRECATED
-#  define LIBCPP_HOCON_DEPRECATED 
+#  define LIBCPP_HOCON_DEPRECATED __attribute__ ((__deprecated__))
 #endif
 
 #ifndef LIBCPP_HOCON_DEPRECATED_EXPORT
@@ -39,4 +39,4 @@
 #  endif
 #endif
 
-#endif
+#endif /* LIBCPP_HOCON_EXPORT_H */
